@@ -31,8 +31,8 @@ class Gaussian(object):
         :return: surface brightness at (x, y)
         """
         c = amp / (2 * np.pi * sigma**2)
-        R2 = (x - center_x) ** 2 / sigma**2 + (y - center_y) ** 2 / sigma**2
-        return c * np.exp(-R2 / 2.)
+        r2 = (x - center_x) ** 2 / sigma**2 + (y - center_y) ** 2 / sigma**2
+        return c * np.exp(-r2 / 2.)
 
     def total_flux(self, amp, sigma, center_x=0, center_y=0):
         """
@@ -94,8 +94,6 @@ class GaussianEllipse(object):
         """
         total integrated flux of profile
 
-        :param x: coordinate on the sky
-        :param y: coordinate on the sky
         :param amp: amplitude, such that 2D integral leads to this value
         :param sigma: sigma of Gaussian in each direction
         :param e1: eccentricity modulus
