@@ -116,8 +116,7 @@ class MultiPool(Pool):
 
         # The key magic is that we must call r.get() with a timeout, because
         # a Condition.wait() without a timeout swallows KeyboardInterrupts.
-        r = self.map_async(func, iterable, chunksize=chunksize,
-                           callback=callbackwrapper)
+        r = self.map_async(func, iterable, chunksize=chunksize, callback=callbackwrapper)
 
         while True:
             try:
