@@ -17,7 +17,8 @@ class LikelihoodModule(object):
     the key components are:
     - imSim_class: an instance of a class that simulates one (or more) images and returns the likelihood, such as
     ImageModel(), Multiband(), MultiExposure()
-    - param_class: instance of a Param() class that can cast the sorted list of parameters that are sampled into the conventions of the imSim_class
+    - param_class: instance of a Param() class that can cast the sorted list of parameters that are sampled into the
+    conventions of the imSim_class
 
     Additional arguments are supported for adding a time-delay likelihood etc (see __init__ definition)
     """
@@ -28,12 +29,12 @@ class LikelihoodModule(object):
                  source_marg=False, linear_prior=None, restrict_image_number=False,
                  max_num_images=None, bands_compute=None, time_delay_likelihood=False,
                  image_likelihood_mask_list=None,
-                 flux_ratio_likelihood=False, kwargs_flux_compute={}, prior_lens=[], prior_source=[],
-                 prior_extinction=[], prior_lens_light=[], prior_ps=[], prior_special=[], prior_lens_kde=[],
-                 prior_source_kde=[], prior_lens_light_kde=[], prior_ps_kde=[], prior_special_kde=[],
-                 prior_extinction_kde=[], prior_lens_lognormal=[], prior_source_lognormal=[],
-                 prior_extinction_lognormal=[], prior_lens_light_lognormal=[], prior_ps_lognormal=[],
-                 prior_special_lognormal=[], custom_logL_addition=None, kwargs_pixelbased=None):
+                 flux_ratio_likelihood=False, kwargs_flux_compute=None, prior_lens=None, prior_source=None,
+                 prior_extinction=None, prior_lens_light=None, prior_ps=None, prior_special=None, prior_lens_kde=None,
+                 prior_source_kde=None, prior_lens_light_kde=None, prior_ps_kde=None, prior_special_kde=None,
+                 prior_extinction_kde=None, prior_lens_lognormal=None, prior_source_lognormal=None,
+                 prior_extinction_lognormal=None, prior_lens_light_lognormal=None, prior_ps_lognormal=None,
+                 prior_special_lognormal=None, custom_logL_addition=None, kwargs_pixelbased=None):
         """
         initializing class
 
@@ -44,12 +45,14 @@ class LikelihoodModule(object):
         :param source_position_likelihood: bool, if True, ray-traces image positions back to source plane and evaluates
         relative errors in respect ot the position_uncertainties in the image plane
         :param check_bounds:  bool, option to punish the hard bounds in parameter space
-        :param check_matched_source_position: bool, option to check whether point source positi gon solver finds a
+        :param check_matched_source_position: bool, option to check whether point source position of solver finds a
          solution to match all the image positions in the same source plane coordinate
-        :param astrometric_likelihood: bool, additional likelihood term of the predicted vs modelled point source position
-        :param flaot, image_position_uncertainty: 1-sigma Gaussian uncertainty on the point source position
+        :param astrometric_likelihood: bool, additional likelihood term of the predicted vs modelled point source
+         position
+        :param image_position_uncertainty: float, 1-sigma Gaussian uncertainty on the point source position
          (only used if point_source_likelihood=True)
-        :param check_positive_flux: bool, option to punish models that do not have all positive linear amplitude parameters
+        :param check_positive_flux: bool, option to punish models that do not have all positive linear amplitude
+         parameters
         :param source_position_tolerance: float, punishment of check_solver occurs when image positions are predicted
          further away than this number
         :param image_likelihood_mask_list: list of boolean 2d arrays of size of images marking the pixels to be
@@ -87,6 +90,8 @@ class LikelihoodModule(object):
         self._time_delay_likelihood = time_delay_likelihood
         self._image_likelihood = image_likelihood
         self._flux_ratio_likelihood = flux_ratio_likelihood
+        if kwargs_flux_compute is None:
+            kwargs_flux_compute = {}
         self._kwargs_flux_compute = kwargs_flux_compute
         self._check_bounds = check_bounds
         self._custom_logL_addition = custom_logL_addition
@@ -162,7 +167,7 @@ class LikelihoodModule(object):
         # update model instance in case of changes affecting it (i.e. redshift sampling in multi-plane)
         self._update_model(kwargs_special)
         # generate image and computes likelihood
-        self._reset_point_source_cache(bool=True)
+        self._reset_point_source_cache(bool_input=True)
         logL = 0
 
         if self._image_likelihood is True:
@@ -193,8 +198,8 @@ class LikelihoodModule(object):
             logL += logL_cond
             if verbose is True:
                 print('custom added logL = %s' % logL_cond)
-        self._reset_point_source_cache(bool=False)
-        return logL#, None
+        self._reset_point_source_cache(bool_input=False)
+        return logL  # , None
 
     @staticmethod
     def check_bounds(args, lowerLimit, upperLimit, verbose=False):
@@ -256,9 +261,9 @@ class LikelihoodModule(object):
         return -self.logL(a)
 
     @staticmethod
-    def _unpack_data(multi_band_list=[], multi_band_type='multi-linear', time_delays_measured=None,
-                     time_delays_uncertainties=None, flux_ratios=None, flux_ratio_errors=None, ra_image_list=[],
-                     dec_image_list=[]):
+    def _unpack_data(multi_band_list=None, multi_band_type='multi-linear', time_delays_measured=None,
+                     time_delays_uncertainties=None, flux_ratios=None, flux_ratio_errors=None, ra_image_list=None,
+                     dec_image_list=None):
         """
 
         :param multi_band_list: list of [[kwargs_data, kwargs_psf, kwargs_numerics], [], ...]
@@ -269,13 +274,19 @@ class LikelihoodModule(object):
         :param flux_ratio_errors: error in flux ratio measurement
         :return:
         """
+        if multi_band_list is None:
+            multi_band_list = []
+        if ra_image_list is None:
+            ra_image_list = []
+        if dec_image_list is None:
+            dec_image_list = []
         return multi_band_list, multi_band_type, time_delays_measured, time_delays_uncertainties, flux_ratios, flux_ratio_errors, ra_image_list, dec_image_list
 
-    def _reset_point_source_cache(self, bool=True):
+    def _reset_point_source_cache(self, bool_input=True):
         self.PointSource.delete_lens_model_cache()
-        self.PointSource.set_save_cache(bool)
+        self.PointSource.set_save_cache(bool_input)
         if self._image_likelihood is True:
-            self.image_likelihood.reset_point_source_cache(bool)
+            self.image_likelihood.reset_point_source_cache(bool_input)
 
     def _update_model(self, kwargs_special):
         """
