@@ -20,20 +20,20 @@ class TestP_JAFFW(object):
         sigma0 = 1.
         Ra, Rs = 0.5, 0.8
         values = self.profile.function(x, y, sigma0, Ra, Rs)
-        assert values[0] == 0.87301557036070054
+        npt.assert_almost_equal(values[0], 0.87301557036070054, decimal=8)
         x = np.array([0])
         y = np.array([0])
         sigma0 = 1.
         Ra, Rs = 0.5, 0.8
         values = self.profile.function(x, y, sigma0, Ra, Rs)
-        assert values[0] == 0.20267440905756931
+        npt.assert_almost_equal(values[0], 0.20267440905756931, decimal=8)
 
         x = np.array([2, 3, 4])
         y = np.array([1, 1, 1])
         values = self.profile.function( x, y, sigma0, Ra, Rs)
-        assert values[0] == 0.87301557036070054
-        assert values[1] == 1.0842781309377669
-        assert values[2] == 1.2588604178849985
+        npt.assert_almost_equal(values[0], 0.87301557036070054, decimal=8)
+        npt.assert_almost_equal(values[1], 1.0842781309377669, decimal=8)
+        npt.assert_almost_equal(values[2], 1.2588604178849985, decimal=8)
 
     def test_derivatives(self):
         x = np.array([1])
@@ -41,8 +41,8 @@ class TestP_JAFFW(object):
         sigma0 = 1.
         Ra, Rs = 0.5, 0.8
         f_x, f_y = self.profile.derivatives( x, y, sigma0, Ra, Rs)
-        assert f_x[0] == 0.11542369603751264
-        assert f_y[0] == 0.23084739207502528
+        npt.assert_almost_equal(f_x[0], 0.11542369603751264, decimal=8)
+        npt.assert_almost_equal(f_y[0], 0.23084739207502528, decimal=8)
         x = np.array([0])
         y = np.array([0])
         f_x, f_y = self.profile.derivatives( x, y, sigma0, Ra, Rs)
@@ -52,10 +52,10 @@ class TestP_JAFFW(object):
         x = np.array([1,3,4])
         y = np.array([2,1,1])
         values = self.profile.derivatives(x, y, sigma0, Ra, Rs)
-        assert values[0][0] == 0.11542369603751264
-        assert values[1][0] == 0.23084739207502528
-        assert values[0][1] == 0.19172866612512479
-        assert values[1][1] == 0.063909555375041588
+        npt.assert_almost_equal(values[0][0], 0.11542369603751264, decimal=8)
+        npt.assert_almost_equal(values[1][0], 0.23084739207502528, decimal=8)
+        npt.assert_almost_equal(values[0][1], 0.19172866612512479, decimal=8)
+        npt.assert_almost_equal(values[1][1], 0.063909555375041588, decimal=8)
 
     def test_hessian(self):
         x = np.array([1])
@@ -63,18 +63,14 @@ class TestP_JAFFW(object):
         sigma0 = 1.
         Ra, Rs = 0.5, 0.8
         f_xx, f_xy, f_yx, f_yy = self.profile.hessian(x, y, sigma0, Ra, Rs)
-        assert f_xx[0] == 0.077446121589827679
-        assert f_yy[0] == -0.036486601753227141
-        assert f_xy[0] == -0.075955148895369876
+        npt.assert_almost_equal(f_xx[0], 0.077446121589827679, decimal=8)
+        npt.assert_almost_equal(f_yy[0], -0.036486601753227141, decimal=8)
+        npt.assert_almost_equal(f_xy[0], -0.075955148895369876, decimal=8)
         x = np.array([1,3,4])
         y = np.array([2,1,1])
         values = self.profile.hessian(x, y, sigma0, Ra, Rs)
-        assert values[0][0] == 0.077446121589827679
-        assert values[3][0] == -0.036486601753227141
-        assert values[1][0] == -0.075955148895369876
-        assert values[0][1] == -0.037260794616683197
-        assert values[3][1] == 0.052668405375961035
-        assert values[1][1] == -0.033723449997241584
+        npt.assert_almost_equal(values[0][0], 0.077446121589827679, decimal=8)
+        npt.assert_almost_equal(values[3][0], -0.036486601753227141, decimal=8)
         npt.assert_almost_equal(values[1][0], values[2][0], decimal=8)
 
     def test_mass_tot(self):
